/* A ceelog event.

Copyright (C) 2012 Red Hat, Inc. All rights reserved.
This copyrighted material is made available to anyone wishing to use, modify,
copy, or redistribute it subject to the terms and conditions of the GNU General
Public License v.2.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
Street, Fifth Floor, Boston, MA 02110-1301, USA.

Author: Miloslav Trmač <mitr@redhat.com> */

#ifndef CEELOG_EVENT_H__
#define CEELOG_EVENT_H__

#include <glib.h>

G_BEGIN_DECLS

/* A ceelog event. */
struct ceelog_event;

struct json_object;

/* Free EVENT. */
extern void ceelog_event_free (struct ceelog_event *event);

/* Return a syslog facility of EVENT, or -1 if not available. */
extern int ceelog_event_get_facility (struct ceelog_event *event);

/* Return a syslog priority of EVENT, or -1 if not available. */
extern int ceelog_event_get_priority (struct ceelog_event *event);

/* Return a timestamp EVENT, or -1 if not available. */
extern time_t ceelog_event_get_timestamp (struct ceelog_event *event);

/* Return host name of EVENT (for g_free ()), or NULL if not available.
   This is the unmodified host name or IP address from the event, without any
   canonicalization. */
extern char *ceelog_event_get_hostname (struct ceelog_event *event);

/* Return tag of EVENT (for g_free ()), or NULL if not available.
   PID, if any, is not included. */
extern char *ceelog_event_get_tag (struct ceelog_event *event);

/* Return the message of EVENT (for g_free ()).
   For JSON messages with a "msg" field, returns the "msg" field only.
   For any other messages, this contains all text after the tag and PID, if any,
   with the leading ':' and ' ' stripped. */
extern char *ceelog_event_get_message (struct ceelog_event *event);

/* Return the JSON data in EVENT (for json_object_put ()), or NULL if not
   present.
   The JSON data is unmodified (metadata in the text part is not added,
   JSON variants of the text part metadata is not removed).  The caller must
   not modify the data. */
extern struct json_object *ceelog_event_get_json (struct ceelog_event *event);

/* Return a best possible representation of EVENT as a string, for g_free ().
   The string does not end with any line terminator.  Preserving the original
   representation is preferred to converting the data into an ideal canonical
   format. */
extern char *ceelog_event_to_string (struct ceelog_event *event);

G_END_DECLS

#endif
