/* ceelog event sources, providing events in order.

Copyright (C) 2012 Red Hat, Inc. All rights reserved.
This copyrighted material is made available to anyone wishing to use, modify,
copy, or redistribute it subject to the terms and conditions of the GNU General
Public License v.2.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
Street, Fifth Floor, Boston, MA 02110-1301, USA.

Author: Miloslav Trmač <mitr@redhat.com> */

#ifndef CEELOG_SOURCE_H__
#define CEELOG_SOURCE_H__

#include <glib.h>

G_BEGIN_DECLS

 /* Generic event source facilities */

/* A ceelog event source.  It can be used to read events in order, and may
   support seeking back to a previously encountered position. */
struct ceelog_source;

struct ceelog_event;

/* Free SOURCE. */
extern void ceelog_source_free (struct ceelog_source *source);

/* Read the next event from SOURCE.  If no event is currently available, but
   it may arrive later, block until it is available.

   Return the event (for ceelog_event_free ()) if it is available, or NULL if
   no more events will arrive (without setting ERROR), or NULL on error. */
extern struct ceelog_event *ceelog_source_read_event
	(struct ceelog_source *source, GError **error);

/* Read the next event from SOURCE.  If no event is currently available,
   fail with CEELOG_ERROR_WOULD_BLOCK.

   Return the event (for ceelog_event_free ()) if it is available, or NULL if
   no more events will arrive (without setting ERROR), or NULL on error. */
extern struct ceelog_event *ceelog_source_read_event_nonblocking
	(struct ceelog_source *source, GError **error);

 /* Specific sources */

/* Open a static text file at PATH as an event source.
   Return the event source (for ceelog_source_free ()), or NULL on error.

   "Static" means that events are not expected to be appended to the file while
   we are reading it, and EOF is final. */
extern struct ceelog_source *ceelog_source_new_static_file (const char *path,
							    GError **error);

/* Open text log file at PATH as an event source.
   Return the event source (for ceelog_source_free ()), or NULL on error. */
extern struct ceelog_source *ceelog_source_new_log_file (const char *path,
                                GError **error);

/* Open the system default event source.
   Return the event source (for ceelog_source_free ()), or NULL on error.
   Usually, this is the function applications should be using. */
extern struct ceelog_source *ceelog_source_new_default (GError **error);

G_END_DECLS

#endif
